using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media.Animation;

namespace Telerik.Windows.Controls
{
	/// <summary>
	/// 
	/// </summary>
	public class RadSlideTransition : RadTransition
	{
		private Orientation orientation = Orientation.Vertical;
		private double pixelsToAnimate = 200;
		private ExponentialEase easing = new ExponentialEase();
		private Duration duration = new Duration(TimeSpan.FromMilliseconds(200));

		/// <summary>
		/// Initializes a new instance of the <see cref="RadSlideTransition"/> class.
		/// </summary>
		public RadSlideTransition()
		{
			this.easing.EasingMode = EasingMode.EaseInOut;
			this.easing.Exponent = 6;
		}

		/// <summary>
		/// Animation that will be played when the content has been loaded, when going forward.
		/// </summary>
		/// <value></value>
		/// /// 
		/// <remarks>
		/// If not specified the animation will be autogenerated as a clone of the ForwardOutAnimation.
		/// </remarks>
		public override RadAnimation ForwardInAnimation
		{
			get
			{
				RadMoveAndFadeAnimation forwardInAnimation = new RadMoveAndFadeAnimation()
				{
					Duration = this.duration,
					Easing = this.easing
				};

				Point moveInAnimationStartPoint = new Point(0, this.pixelsToAnimate);
				Point moveInAnimationEndPoint = new Point(0, 0);
				if (this.Orientation == Orientation.Horizontal)
				{
					moveInAnimationStartPoint = new Point(this.pixelsToAnimate, 0);
					moveInAnimationEndPoint = new Point(0, 0);
				}

				forwardInAnimation.MoveAnimation.StartPoint = moveInAnimationStartPoint;
				forwardInAnimation.MoveAnimation.EndPoint = moveInAnimationEndPoint;

				forwardInAnimation.FadeAnimation.StartOpacity = 0;
				forwardInAnimation.FadeAnimation.EndOpacity = 1;

				return forwardInAnimation;
			}
		}

		/// <summary>
		/// Animation that will be played when the content has been unloaded, when going forward.
		/// </summary>
		/// <value></value>
		public override RadAnimation ForwardOutAnimation
		{
			get
			{
				RadMoveAndFadeAnimation forwardOutAnimation = new RadMoveAndFadeAnimation()
				{
					Duration = this.duration,
					Easing = this.easing
				};

				Point moveOutAnimationStartPoint = new Point(0, 0);
				Point moveOutAnimationEndPoint = new Point(0, -1 * this.pixelsToAnimate);
				if (this.Orientation == Orientation.Horizontal)
				{
					moveOutAnimationStartPoint = new Point(0, 0);
					moveOutAnimationEndPoint = new Point(-1 * this.pixelsToAnimate, 0);
				}

				forwardOutAnimation.MoveAnimation.StartPoint = moveOutAnimationStartPoint;
				forwardOutAnimation.MoveAnimation.EndPoint = moveOutAnimationEndPoint;

				forwardOutAnimation.FadeAnimation.StartOpacity = 1;
				forwardOutAnimation.FadeAnimation.EndOpacity = 0;

				return forwardOutAnimation;
			}
		}

		/// <summary>
		/// Gets or sets the orientation.
		/// </summary>
		/// <value>The orientation.</value>
		public Orientation Orientation
		{
			get
			{
				return this.orientation;
			}
			set
			{
				this.orientation = value;
			}
		}
	}
}
